import 'dart:io';

import 'package:dotup_flutter_widgets/src/layout/runtime.dart';
import 'package:flutter/foundation.dart';

class PlatformValue<T> {
  PlatformValue({
    T? android,
    T? ios,
    T? linux,
    T? macOS,
    T? fallback,
    T? windows,
    T? web,
    T? tablet,
    T? phone,
    T? desktop,
  })  : _android = android,
        _ios = ios,
        _linux = linux,
        _macOS = macOS,
        _fallback = fallback,
        _windows = windows,
        _web = web,
        _tablet = tablet,
        _phone = phone,
        _desktop = desktop;

  final T? _android;
  T get android => _android ?? _getMobileDeviceValue() ?? _fallback!;

  final T? _ios;
  T get ios => _ios ?? _getMobileDeviceValue() ?? _fallback!;

  final T? _macOS;
  T get macOS => _macOS ?? _desktop ?? _fallback!;

  final T? _linux;
  T get linux => _linux ?? _desktop ?? _fallback!;

  final T? _windows;
  T get windows => _windows ?? _desktop ?? _fallback!;

  final T? _fallback;
  T get fallback => _fallback!;

  final T? _web;
  T get web => _web ?? _fallback!;

  final T? _tablet;
  T get tablet => _tablet ?? _fallback!;

  final T? _phone;
  T get phone => _phone ?? _fallback!;

  final T? _desktop;
  T get desktop => _desktop ?? _fallback!;

  T get value => _getValue();

  T _getValue() {
    if (kIsWeb) {
      return web;
    }
    switch (Platform.operatingSystem) {
      case "linux":
        return linux;
      case "macos":
        return macOS;
      case "windows":
        return windows;
      case "android":
        return android;
      case "ios":
        return ios;
      default:
        return fallback;
    }
  }

// Call this only from ios and android
  T? _getMobileDeviceValue() {
    return Runtime.info().isPhone ? _phone : _tablet;
  }
}
