import 'package:flutter/material.dart';

enum ScreenSize {
  unknown,
  xsmall,
  small,
  medium,
  large,
  xlarge,
}

class Responsive {
  static late double xlargeWidth = 1400;
  static late double largeWidth = 1200;
  static late double mediumWidth = 1024;
  static late double smallWidth = 380;
  static late double xsmallWidth = 300;

  static bool isXL(BuildContext context) => isExtraLargeScreen(context);
  static bool isExtraLargeScreen(BuildContext context) {
    return MediaQuery.of(context).size.width >= xlargeWidth;
  }

  static bool isL(BuildContext context) => isLargeScreen(context);
  static bool isLargeScreen(BuildContext context) {
    final size = MediaQuery.of(context).size;
    return size.width >= largeWidth && size.width < xlargeWidth;
  }

  static bool isM(BuildContext context) => isMediumScreen(context);
  static bool isMediumScreen(BuildContext context) {
    final size = MediaQuery.of(context).size;
    return size.width >= mediumWidth && size.width < largeWidth;
  }

  static bool isS(BuildContext context) => isSmallScreen(context);
  static bool isSmallScreen(BuildContext context) {
    final size = MediaQuery.of(context).size;
    return size.width >= smallWidth && size.width < mediumWidth;
  }

  static bool isXS(BuildContext context) => isExtraSmallScreen(context);
  static bool isExtraSmallScreen(BuildContext context) {
    return MediaQuery.of(context).size.width < smallWidth;
  }

  static ScreenSize screenSize(BuildContext context) {
    if (isExtraSmallScreen(context)) {
      return ScreenSize.xsmall;
    } else if (isSmallScreen(context)) {
      return ScreenSize.small;
    } else if (isMediumScreen(context)) {
      return ScreenSize.medium;
    } else if (isLargeScreen(context)) {
      return ScreenSize.large;
    } else if (isExtraLargeScreen(context)) {
      return ScreenSize.xlarge;
    } else {
      return ScreenSize.unknown;
    }
  }
}
